==> yawp-1.21.4-fabric-0.5.2-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/player/AxeItemMixin.java <==
package de.z0rdak.yawp.mixin.flag.player;

import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1743;
import net.minecraft.class_1838;
import net.minecraft.class_2338;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import static de.z0rdak.yawp.core.flag.RegionFlag.AXE_STRIP;
import static de.z0rdak.yawp.core.flag.RegionFlag.TOOL_SECONDARY_USE;
import static de.z0rdak.yawp.handler.HandlerUtil.*;
import static de.z0rdak.yawp.api.MessageSender.sendFlagMsg;

@Mixin(class_1743.class)
public abstract class AxeItemMixin {

    @Inject(method = "useOn", at = @At(value = "HEAD"), cancellable = true, allow = 1)
    public void onUseAxeOnBlock(class_1838 context, CallbackInfoReturnable<class_1269> cir) {
        class_2338 pos = context.method_8037();
        class_1657 player = context.method_8036();
        if (isServerSide(context.method_8045()) && player != null) {
            FlagCheckEvent checkEvent = new FlagCheckEvent(pos, TOOL_SECONDARY_USE, getDimKey(context.method_8045()), player);
            if (Services.EVENT.post(checkEvent)) {
                return;
            }
            processCheck(checkEvent, deny -> {
                sendFlagMsg(deny);
                cir.setReturnValue(class_1269.field_5811);
            });

            checkEvent = new FlagCheckEvent(pos, AXE_STRIP, getDimKey(context.method_8045()), player);
            if (Services.EVENT.post(checkEvent)) {
                return;
            }
            processCheck(checkEvent, deny -> {
                sendFlagMsg(deny);
                cir.setReturnValue(class_1269.field_5811);
            });
        }
    }
}

==> yawp-1.21.6-fabric-0.6.1-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/player/AxeItemMixin.java <==
package de.z0rdak.yawp.mixin.flag.player;

import de.z0rdak.yawp.api.FlagEvaluator;
import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1743;
import net.minecraft.class_1838;
import net.minecraft.class_2338;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import static de.z0rdak.yawp.core.flag.RegionFlag.AXE_STRIP;
import static de.z0rdak.yawp.core.flag.RegionFlag.TOOL_SECONDARY_USE;
import static de.z0rdak.yawp.handler.HandlerUtil.*;
import static de.z0rdak.yawp.api.MessageSender.sendFlagMsg;

@Mixin(class_1743.class)
public abstract class AxeItemMixin {

    @Inject(method = "useOn", at = @At(value = "HEAD"), cancellable = true, allow = 1)
    public void onUseAxeOnBlock(class_1838 context, CallbackInfoReturnable<class_1269> cir) {
        class_2338 pos = context.method_8037();
        class_1657 player = context.method_8036();
        if (isServerSide(context.method_8045()) && player != null) {
            FlagCheckEvent checkEvent = new FlagCheckEvent(pos, TOOL_SECONDARY_USE, getDimKey(context.method_8045()), player);
            if (Services.EVENT.post(checkEvent)) {
                return;
            }
            FlagEvaluator.processCheck(checkEvent, deny -> {
                sendFlagMsg(deny);
                cir.setReturnValue(class_1269.field_5811);
            });

            checkEvent = new FlagCheckEvent(pos, AXE_STRIP, getDimKey(context.method_8045()), player);
            if (Services.EVENT.post(checkEvent)) {
                return;
            }
            FlagEvaluator.processCheck(checkEvent, deny -> {
                sendFlagMsg(deny);
                cir.setReturnValue(class_1269.field_5811);
            });
        }
    }
}
